@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2006-2016 by Jakob Schröter <js@camaya.net>
+  Copyright (c) 2006-2019 by Jakob Schröter <js@camaya.net>
   This file is part of the gloox library. http://camaya.net/gloox
 
   This software is distributed under a license. The full license
@@ -53,6 +53,17 @@ namespace gloox
        */
       virtual void handleBytestreamData( Bytestream* bs, const std::string& data ) = 0;
 
+      /**
+       * Reimplement this function to be notified when the remote end has
+       * received and acknowledged a single data packet. This packet may be
+       * smaller than the chunk that was fed into Bytream::send() due to internal
+       * chunk size limits. so this callback may be called multiple times for
+       * each call to Bytestream::send(). it can be used to implement burst limits.
+       * @param bs The bytestream.
+       * @since 1.0.20
+       */
+      virtual void handleBytestreamDataAck( Bytestream* bs ) {}
+      
       /**
        * Notifies about an error occuring while using a bytestream.
        * When this handler is called the stream has already been closed.
