@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2005-2017 by Jakob Schröter <js@camaya.net>
+  Copyright (c) 2005-2019 by Jakob Schröter <js@camaya.net>
   This file is part of the gloox library. http://camaya.net/gloox
 
   This software is distributed under a license. The full license
@@ -1278,7 +1278,7 @@ namespace gloox
         err = StreamErrorUnsupportedStanzaType;
       else if( name == "unsupported-version" )
         err = StreamErrorUnsupportedVersion;
-      else if( name == "xml-not-well-formed" )
+      else if( name == "not-well-formed" )
         err = StreamErrorXmlNotWellFormed;
       else if( name == "text" )
       {
@@ -1691,7 +1691,7 @@ namespace gloox
       if( (*it1)->target().full() == msg.from().full() &&
             ( msg.thread().empty()
               || (*it1)->threadID() == msg.thread()
-              || (*it1)->honorThreadID() ) &&
+              || !(*it1)->honorThreadID() ) &&
 // FIXME don't use '== 0' here
             ( (*it1)->types() & msg.subtype() || (*it1)->types() == 0 ) )
       {
@@ -1706,7 +1706,7 @@ namespace gloox
       if( (*it1)->target().bare() == msg.from().bare() &&
             ( msg.thread().empty()
               || (*it1)->threadID() == msg.thread()
-              || (*it1)->honorThreadID() ) &&
+              || !(*it1)->honorThreadID() ) &&
 // FIXME don't use '== 0' here
             ( (*it1)->types() & msg.subtype() || (*it1)->types() == 0 ) )
       {
