@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2005-2016 by Jakob Schröter <js@camaya.net>
+  Copyright (c) 2005-2019 by Jakob Schröter <js@camaya.net>
   This file is part of the gloox library. http://camaya.net/gloox
 
   This software is distributed under a license. The full license
@@ -1096,7 +1096,7 @@ namespace gloox
       std::string m_ntlmDomain;
       bool m_customConnection;
 
-      int m_uniqueBaseId;
+      std::string m_uniqueBaseId;
       util::AtomicRefCount m_nextId;
 
       int m_smSent;
