@@ -28,8 +28,7 @@ namespace gloox
 
   Parser::~Parser()
   {
-    delete m_root;
-    delete m_xmlnss;
+    cleanup( true );
   }
 
   Parser::DecodeState Parser::decode( std::string::size_type& pos, const std::string& data )
